@@ -16,6 +16,7 @@ ALL_ROUTES = [
     ('account:invoices', 'SoftLayer.CLI.account.invoices:cli'),
     ('account:events', 'SoftLayer.CLI.account.events:cli'),
     ('account:event-detail', 'SoftLayer.CLI.account.event_detail:cli'),
+    ('account:licenses', 'SoftLayer.CLI.account.licenses:cli'),
     ('account:summary', 'SoftLayer.CLI.account.summary:cli'),
     ('account:billing-items', 'SoftLayer.CLI.account.billing_items:cli'),
     ('account:item-detail', 'SoftLayer.CLI.account.item_detail:cli'),
@@ -45,6 +46,7 @@ ALL_ROUTES = [
     ('virtual:upgrade', 'SoftLayer.CLI.virt.upgrade:cli'),
     ('virtual:usage', 'SoftLayer.CLI.virt.usage:cli'),
     ('virtual:credentials', 'SoftLayer.CLI.virt.credentials:cli'),
+    ('virtual:authorize-storage', 'SoftLayer.CLI.virt.authorize_storage:cli'),
     ('virtual:capacity', 'SoftLayer.CLI.virt.capacity:cli'),
     ('virtual:placementgroup', 'SoftLayer.CLI.virt.placementgroup:cli'),
     ('virtual:migrate', 'SoftLayer.CLI.virt.migrate:cli'),
@@ -60,6 +62,7 @@ ALL_ROUTES = [
 
     ('cdn', 'SoftLayer.CLI.cdn'),
     ('cdn:detail', 'SoftLayer.CLI.cdn.detail:cli'),
+    ('cdn:edit', 'SoftLayer.CLI.cdn.edit:cli'),
     ('cdn:list', 'SoftLayer.CLI.cdn.list:cli'),
     ('cdn:origin-add', 'SoftLayer.CLI.cdn.origin_add:cli'),
     ('cdn:origin-list', 'SoftLayer.CLI.cdn.origin_list:cli'),
@@ -118,6 +121,14 @@ ALL_ROUTES = [
     ('block:volume-convert', 'SoftLayer.CLI.block.convert:cli'),
     ('block:volume-set-note', 'SoftLayer.CLI.block.set_note:cli'),
 
+    ('email', 'SoftLayer.CLI.email'),
+    ('email:list', 'SoftLayer.CLI.email.list:cli'),
+    ('email:detail', 'SoftLayer.CLI.email.detail:cli'),
+    ('email:edit', 'SoftLayer.CLI.email.edit:cli'),
+
+    ('licenses', 'SoftLayer.CLI.licenses'),
+    ('licenses:create-options', 'SoftLayer.CLI.licenses.create_options:cli'),
+
     ('event-log', 'SoftLayer.CLI.event_log'),
     ('event-log:get', 'SoftLayer.CLI.event_log.get:cli'),
     ('event-log:types', 'SoftLayer.CLI.event_log.types:cli'),
@@ -211,6 +222,10 @@ ALL_ROUTES = [
     ('nas:list', 'SoftLayer.CLI.nas.list:cli'),
     ('nas:credentials', 'SoftLayer.CLI.nas.credentials:cli'),
 
+    ('licenses', 'SoftLayer.CLI.licenses'),
+    ('licenses:create', 'SoftLayer.CLI.licenses.create:cli'),
+    ('licenses:cancel', 'SoftLayer.CLI.licenses.cancel:cli'),
+
     ('object-storage', 'SoftLayer.CLI.object_storage'),
 
     ('object-storage:accounts', 'SoftLayer.CLI.object_storage.list_accounts:cli'),
@@ -227,13 +242,10 @@ ALL_ROUTES = [
     ('order:place-quote', 'SoftLayer.CLI.order.place_quote:cli'),
     ('order:quote-list', 'SoftLayer.CLI.order.quote_list:cli'),
     ('order:quote-detail', 'SoftLayer.CLI.order.quote_detail:cli'),
+    ('order:quote-save', 'SoftLayer.CLI.order.quote_save:cli'),
     ('order:quote', 'SoftLayer.CLI.order.quote:cli'),
     ('order:lookup', 'SoftLayer.CLI.order.lookup:cli'),
 
-    ('rwhois', 'SoftLayer.CLI.rwhois'),
-    ('rwhois:edit', 'SoftLayer.CLI.rwhois.edit:cli'),
-    ('rwhois:show', 'SoftLayer.CLI.rwhois.show:cli'),
-
     ('hardware', 'SoftLayer.CLI.hardware'),
     ('hardware:bandwidth', 'SoftLayer.CLI.hardware.bandwidth:cli'),
     ('hardware:cancel', 'SoftLayer.CLI.hardware.cancel:cli'),
@@ -256,8 +268,10 @@ ALL_ROUTES = [
     ('hardware:rescue', 'SoftLayer.CLI.hardware.power:rescue'),
     ('hardware:ready', 'SoftLayer.CLI.hardware.ready:cli'),
     ('hardware:toggle-ipmi', 'SoftLayer.CLI.hardware.toggle_ipmi:cli'),
+    ('hardware:authorize-storage', 'SoftLayer.CLI.hardware.authorize_storage:cli'),
     ('hardware:dns-sync', 'SoftLayer.CLI.hardware.dns:cli'),
     ('hardware:storage', 'SoftLayer.CLI.hardware.storage:cli'),
+    ('hardware:upgrade', 'SoftLayer.CLI.hardware.upgrade:cli'),
 
     ('securitygroup', 'SoftLayer.CLI.securitygroup'),
     ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
@@ -333,9 +347,11 @@ ALL_ROUTES = [
     ('user:vpn-subnet', 'SoftLayer.CLI.user.vpn_subnet:cli'),
 
     ('vlan', 'SoftLayer.CLI.vlan'),
+    ('vlan:create', 'SoftLayer.CLI.vlan.create:cli'),
     ('vlan:detail', 'SoftLayer.CLI.vlan.detail:cli'),
     ('vlan:edit', 'SoftLayer.CLI.vlan.edit:cli'),
     ('vlan:list', 'SoftLayer.CLI.vlan.list:cli'),
+    ('vlan:cancel', 'SoftLayer.CLI.vlan.cancel:cli'),
 
     ('summary', 'SoftLayer.CLI.summary:cli'),
 
