@@ -1020,3 +1020,190 @@ getAllTopLevelBillingItems = [
         "resourceTableId": 777777
     }
 ]
+
+getNetworkStorage = [
+    {
+        "accountId": 1111111,
+        "capacityGb": 20,
+        "createDate": "2016-01-21T12:11:07-06:00",
+        "id": 1234567,
+        "nasType": "ISCSI",
+        "username": "SL01SEL301234-11",
+    },
+    {
+        "accountId": 1111111,
+        "capacityGb": 20,
+        "createDate": "2015-04-29T07:55:55-06:00",
+        "id": 4917123,
+        "nasType": "NAS",
+        "username": "SL01SEV1234567_111"
+    }
+]
+
+getRouters = [
+    {
+        "accountId": 1,
+        "bareMetalInstanceFlag": 0,
+        "domain": "softlayer.com",
+        "fullyQualifiedDomainName": "fcr01a.ams01.softlayer.com",
+        "hardwareStatusId": 5,
+        "hostname": "fcr01a.ams01",
+        "id": 123456,
+        "serviceProviderId": 1,
+        "topLevelLocation": {
+            "id": 265592,
+            "longName": "Amsterdam 1",
+            "name": "ams01",
+            "statusId": 2
+        }
+    }]
+
+getNetworkStorage = [
+    {
+        "accountId": 1111111,
+        "capacityGb": 20,
+        "createDate": "2016-01-21T12:11:07-06:00",
+        "id": 1234567,
+        "nasType": "ISCSI",
+        "username": "SL01SEL301234-11",
+    },
+    {
+        "accountId": 1111111,
+        "capacityGb": 20,
+        "createDate": "2015-04-29T07:55:55-06:00",
+        "id": 4917123,
+        "nasType": "NAS",
+        "username": "SL01SEV1234567_111"
+    }
+]
+
+getNetworkMessageDeliveryAccounts = [
+    {
+        "accountId": 147258,
+        "createDate": "2020-07-06T10:29:11-06:00",
+        "id": 1232123,
+        "typeId": 21,
+        "username": "test_CLI@ie.ibm.com",
+        "vendorId": 1,
+        "type": {
+            "description": "Delivery of messages through e-mail",
+            "id": 21,
+            "keyName": "EMAIL",
+            "name": "Email"
+        },
+        "vendor": {
+            "id": 1,
+            "keyName": "SENDGRID",
+            "name": "SendGrid"
+        },
+        "emailAddress": "test_CLI@ie.ibm.com",
+        "smtpAccess": "1"
+    }
+]
+
+getActiveAccountLicenses = [{
+    "accountId": 123456,
+    "capacity": "4",
+    "key": "Y8GNS-7QRNG-OUIJO-MATEI-5GJRM",
+    "units": "CPU",
+    "billingItem": {
+        "allowCancellationFlag": 1,
+        "categoryCode": "software_license",
+        "cycleStartDate": "2021-06-03T23:11:22-06:00",
+        "description": "vCenter Server Appliance 6.0",
+        "id": 741258963,
+        "laborFee": "0",
+        "laborFeeTaxRate": "0",
+        "oneTimeFee": "0",
+        "oneTimeFeeTaxRate": "0",
+        "orderItemId": 963258741,
+        "recurringFee": "0",
+        "recurringFeeTaxRate": "0",
+        "recurringMonths": 1,
+        "serviceProviderId": 1,
+        "setupFee": "0",
+        "setupFeeTaxRate": "0"
+    },
+    "softwareDescription": {
+        "controlPanel": 0,
+        "id": 15963,
+        "licenseTermValue": 0,
+        "longDescription": "VMware vCenter 6.0",
+        "manufacturer": "VMware",
+        "name": "vCenter",
+        "operatingSystem": 0,
+        "version": "6.0",
+        "virtualLicense": 0,
+        "virtualizationPlatform": 0,
+        "requiredUser": "administrator@vsphere.local"
+    }
+},
+    {
+        "accountId": 123456,
+        "capacity": "4",
+        "key": "TSZES-SJF85-04GLD-AXA64-8O1EO",
+        "units": "CPU",
+        "billingItem": {
+            "allowCancellationFlag": 1,
+            "categoryCode": "software_license",
+            "description": "vCenter Server Appliance 6.x",
+            "id": 36987456,
+            "laborFee": "0",
+            "laborFeeTaxRate": "0",
+            "oneTimeFee": "0",
+            "oneTimeFeeTaxRate": "0",
+            "orderItemId": 25839,
+            "recurringFee": "0",
+            "recurringFeeTaxRate": "0",
+            "recurringMonths": 1,
+            "serviceProviderId": 1,
+            "setupFee": "0",
+            "setupFeeTaxRate": "0"
+        },
+        "softwareDescription": {
+            "controlPanel": 0,
+            "id": 1472,
+            "licenseTermValue": 0,
+            "longDescription": "VMware vCenter 6.0",
+            "manufacturer": "VMware",
+            "name": "vCenter",
+            "operatingSystem": 0,
+            "version": "6.0",
+            "virtualLicense": 0,
+            "virtualizationPlatform": 0,
+            "requiredUser": "administrator@vsphere.local"
+        }
+    }
+]
+
+getActiveVirtualLicenses = [{
+    "id": 12345,
+    "ipAddress": "192.168.23.78",
+    "key": "TEST.60220734.0000",
+    "billingItem": {
+        "categoryCode": "control_panel",
+        "description": "Plesk Onyx (Linux) - (Unlimited) - VPS "
+    },
+    "softwareDescription": {
+        "longDescription": "Plesk - Unlimited Domain w/ Power Pack for VPS 17.8.11 Linux",
+        "manufacturer": "Plesk",
+        "name": "Plesk - Unlimited Domain w/ Power Pack for VPS"
+    },
+    "subnet": {
+        "broadcastAddress": "192.168.23.79",
+        "cidr": 28,
+        "gateway": "192.168.23.65",
+        "id": 1973163,
+        "isCustomerOwned": False,
+        "isCustomerRoutable": False,
+        "netmask": "255.255.255.240",
+        "networkIdentifier": "128.116.23.64",
+        "networkVlanId": 123456,
+        "note": "test note",
+        "sortOrder": "1",
+        "subnetType": "ADDITIONAL_PRIMARY",
+        "totalIpAddresses": "16",
+        "usableIpAddressCount": "13",
+        "version": 4
+    }
+}]
