@@ -5,11 +5,13 @@
 
     :license: MIT, see LICENSE for more details.
 """
+import datetime
 import logging
 import socket
 import time
 
 from SoftLayer.decoration import retry
+from SoftLayer import exceptions
 from SoftLayer.exceptions import SoftLayerError
 from SoftLayer.managers import ordering
 from SoftLayer.managers.ticket import TicketManager
@@ -18,7 +20,7 @@ from SoftLayer import utils
 LOGGER = logging.getLogger(__name__)
 
 # Invalid names are ignored due to long method names and short argument names
-# pylint: disable=invalid-name, no-self-use
+# pylint: disable=invalid-name, no-self-use, too-many-lines
 
 EXTRA_CATEGORIES = ['pri_ipv6_addresses',
                     'static_ipv6_addresses',
@@ -237,6 +239,8 @@ class HardwareManager(utils.IdentifierMixin, object):
                 'primaryIpAddress,'
                 'networkManagementIpAddress,'
                 'userData,'
+                'activeComponents[id,hardwareComponentModel['
+                'hardwareGenericComponentModel[id,hardwareComponentType[keyName]]]],'
                 'datacenter,'
                 '''networkComponents[id, status, speed, maxSpeed, name,
                    ipmiMacAddress, ipmiIpAddress, macAddress, primaryIpAddress,
@@ -258,9 +262,10 @@ class HardwareManager(utils.IdentifierMixin, object):
                     passwords[username,password]],'''
                 'billingItem['
                 'id,nextInvoiceTotalRecurringAmount,'
-                'children[nextInvoiceTotalRecurringAmount],'
+                'nextInvoiceChildren[nextInvoiceTotalRecurringAmount],'
                 'orderItem.order.userRecord[username]'
                 '],'
+                'lastTransaction[transactionGroup],'
                 'hourlyBillingFlag,'
                 'tagReferences[id,tag[name,id]],'
                 'networkVlans[id,vlanNumber,networkSpace],'
@@ -786,6 +791,313 @@ class HardwareManager(utils.IdentifierMixin, object):
         return self.client.call('SoftLayer_Product_Package', 'getItemPrices', mask=object_mask, filter=object_filter,
                                 id=package['id'])
 
+    def authorize_storage(self, hardware_id, username_storage):
+        """Authorize File or Block Storage to a Hardware Server.
+
+        :param int hardware_id: Hardware server id.
+        :param string username_storage: Storage username.
+
+        :return: bool.
+        """
+        _filter = {"networkStorage": {"username": {"operation": username_storage}}}
+
+        storage_result = self.client.call('Account', 'getNetworkStorage', filter=_filter)
+
+        if len(storage_result) == 0:
+            raise SoftLayerError("The Storage with username: %s was not found, please"
+                                 " enter a valid storage username" % username_storage)
+
+        storage_template = [
+            {
+                "id": storage_result[0]['id'],
+                "username": username_storage
+            }
+        ]
+
+        result = self.client.call('Hardware', 'allowAccessToNetworkStorageList',
+                                  storage_template, id=hardware_id)
+
+        return result
+
+    def upgrade(self, instance_id, memory=None,
+                nic_speed=None, drive_controller=None,
+                public_bandwidth=None, disk=None, test=False):
+        """Upgrades a hardware server instance.
+
+        :param int instance_id: Instance id of the hardware server to be upgraded.
+        :param int memory: Memory size.
+        :param string nic_speed: Network Port Speed data.
+        :param string drive_controller: Drive Controller data.
+        :param int public_bandwidth: Public keyName data.
+        :param list disk: List of disks to add or upgrade Hardware Server.
+        :param bool test: Test option to verify the request.
+
+        :returns: bool
+        """
+        result = None
+        maintenance_window_id = None
+        upgrade_prices = self._get_upgrade_prices(instance_id)
+        prices = []
+        data = {}
+
+        if memory:
+            data['memory'] = memory
+        if nic_speed:
+            data['nic_speed'] = nic_speed
+        if drive_controller:
+            data['disk_controller'] = drive_controller
+        if public_bandwidth:
+            data['bandwidth'] = public_bandwidth
+
+        server_response = self.get_instance(instance_id)
+        package_id = server_response['billingItem']['package']['id']
+        location_id = server_response['datacenter']['id']
+
+        maintenance_window = datetime.datetime.now(utils.UTC())
+        maintenance_window_detail = self.get_maintenance_windows_detail(location_id)
+        if maintenance_window_detail:
+            maintenance_window_id = maintenance_window_detail.get('id')
+
+        order = {
+            'complexType': 'SoftLayer_Container_Product_Order_Hardware_Server_Upgrade',
+            'properties': [
+                {
+                    'name': 'MAINTENANCE_WINDOW',
+                    'value': maintenance_window.strftime("%Y-%m-%d %H:%M:%S%z")
+                },
+                {
+                    'name': 'MAINTENANCE_WINDOW_ID',
+                    'value': str(maintenance_window_id)
+                }
+
+            ],
+            'hardware': [{'id': int(instance_id)}],
+            'packageId': package_id
+        }
+
+        if disk:
+            prices = self._get_disk_price_list(instance_id, disk)
+            order['prices'] = prices
+
+        for option, value in data.items():
+            price_id = self._get_prices_for_upgrade_option(upgrade_prices, option, value)
+            if not price_id:
+                # Every option provided is expected to have a price
+                raise exceptions.SoftLayerError(
+                    "Unable to find %s option with value %s" % (option, value))
+
+            prices.append({'id': price_id})
+
+            order['prices'] = prices
+
+        if prices:
+            if test:
+                result = self.client['Product_Order'].verifyOrder(order)
+            else:
+                result = self.client['Product_Order'].placeOrder(order)
+        return result
+
+    def get_maintenance_windows_detail(self, location_id):
+        """Get the disks prices to be added or upgraded.
+
+        :param int location_id: Hardware Server location id.
+        :return int:
+        """
+        result = None
+        begin_date_object = datetime.datetime.now()
+        begin_date = begin_date_object.strftime("%Y-%m-%dT00:00:00.0000-06:00")
+        end_date_object = datetime.date.today() + datetime.timedelta(days=30)
+        end_date = end_date_object.strftime("%Y-%m-%dT00:00:00.0000-06:00")
+
+        result_windows = self.client['SoftLayer_Provisioning_Maintenance_Window'].getMaintenanceWindows(begin_date,
+                                                                                                        end_date,
+                                                                                                        location_id)
+        if len(result_windows) > 0:
+            result = result_windows[0]
+
+        return result
+
+    @retry(logger=LOGGER)
+    def get_instance(self, instance_id):
+        """Get details about a hardware server instance.
+
+        :param int instance_id: the instance ID
+        :returns: A dictionary containing a large amount of information about
+                  the specified instance.
+        """
+        mask = [
+            'datacenter,billingItem[id,package[id,keyName],nextInvoiceChildren]'
+        ]
+        mask = "mask[%s]" % ','.join(mask)
+
+        return self.hardware.getObject(id=instance_id, mask=mask)
+
+    def _get_upgrade_prices(self, instance_id):
+        """Following Method gets all the price ids related to upgrading a Hardware Server.
+
+        :param int instance_id: Instance id of the Hardware Server to be upgraded.
+
+        :returns: list
+        """
+        mask = [
+            'id',
+            'locationGroupId',
+            'categories[name,id,categoryCode]',
+            'item[keyName,description,capacity,units]'
+        ]
+        mask = "mask[%s]" % ','.join(mask)
+        return self.hardware.getUpgradeItemPrices(id=instance_id, mask=mask)
+
+    @staticmethod
+    def _get_prices_for_upgrade_option(upgrade_prices, option, value):
+        """Find the price id for the option and value to upgrade. This
+
+        :param list upgrade_prices: Contains all the prices related to a
+        hardware server upgrade.
+        :param string option: Describes type of parameter to be upgraded
+
+        :return: int.
+        """
+        price_id = None
+        option_category = {
+            'memory': 'ram',
+            'nic_speed': 'port_speed',
+            'disk_controller': 'disk_controller',
+            'bandwidth': 'bandwidth'
+        }
+        if 'disk' in option:
+            category_code = option
+        else:
+            category_code = option_category.get(option)
+
+        for price in upgrade_prices:
+            if price.get('categories') is None or price.get('item') is None:
+                continue
+
+            product = price.get('item')
+            for category in price.get('categories'):
+                if not category.get('categoryCode') == category_code:
+                    continue
+
+                if option == 'disk_controller':
+                    if value == product.get('description'):
+                        price_id = price.get('id')
+                elif option == 'nic_speed':
+                    if value.isdigit():
+                        if str(product.get('capacity')) == str(value):
+                            price_id = price.get('id')
+                    else:
+                        split_nic_speed = value.split(" ")
+                        if str(product.get('capacity')) == str(split_nic_speed[0]) and \
+                                split_nic_speed[1] in product.get("description"):
+                            price_id = price.get('id')
+                elif option == 'bandwidth':
+                    if str(product.get('capacity')) == str(value):
+                        price_id = price.get('id')
+                elif 'disk' in option:
+                    if str(product.get('capacity')) == str(value):
+                        price_id = price
+                else:
+                    if str(product.get('capacity')) == str(value):
+                        price_id = price.get('id')
+
+        return price_id
+
+    def _get_disk_price_list(self, instance_id, disk):
+        """Get the disks prices to be added or upgraded.
+
+        :param int instance_id: Hardware Server instance id.
+        :param list disk: List of disks to be added o upgraded to the HW.
+
+        :return list.
+        """
+        prices = []
+        disk_exist = False
+        upgrade_prices = self._get_upgrade_prices(instance_id)
+        server_response = self.get_instance(instance_id)
+        for disk_data in disk:
+            disk_channel = 'disk' + str(disk_data.get('number'))
+            for item in utils.lookup(server_response, 'billingItem', 'nextInvoiceChildren'):
+                if disk_channel == item['categoryCode']:
+                    disk_exist = True
+                    break
+            if disk_exist:
+                disk_price_detail = self._get_disk_price_detail(disk_data, upgrade_prices, disk_channel, 'add_disk')
+                prices.append(disk_price_detail)
+            else:
+                disk_price_detail = self._get_disk_price_detail(disk_data, upgrade_prices, disk_channel, 'resize_disk')
+                prices.append(disk_price_detail)
+
+        return prices
+
+    def _get_disk_price_detail(self, disk_data, upgrade_prices, disk_channel, disk_type):
+        """Get the disk price detail.
+
+        :param disk_data: List of disks to be added or upgraded.
+        :param list upgrade_prices: List of item prices.
+        :param String disk_channel: Disk position.
+        :param String disk_type: Disk type.
+
+        """
+        if disk_data.get('description') == disk_type:
+            if "add" in disk_type:
+                raise SoftLayerError("Unable to add the disk because this already exists.")
+            if "resize" in disk_type:
+                raise SoftLayerError("Unable to resize the disk because this does not exists.")
+        else:
+            price_id = self._get_prices_for_upgrade_option(upgrade_prices, disk_channel,
+                                                           disk_data.get('capacity'))
+            if not price_id:
+                raise SoftLayerError("The item price was not found for %s with 'capacity:' %i" %
+                                     (disk_channel, disk_data.get('capacity')))
+
+            disk_price = {
+                "id": price_id.get('id'),
+                "categories": [
+                    {
+                        "categoryCode": price_id['categories'][0]['categoryCode'],
+                        "id": price_id['categories'][0]['id']
+                    }
+                ]
+            }
+
+        return disk_price
+
+    def get_components(self, hardware_id, mask=None, filter_component=None):
+        """Get details about a hardware components.
+
+        :param int hardware_id: the instance ID
+        :returns: A dictionary containing a large amount of information about
+                  the specified components.
+        """
+        if not mask:
+            mask = 'id,hardwareComponentModel[longDescription,' \
+                   'hardwareGenericComponentModel[description,hardwareComponentType[keyName]],' \
+                   'firmwares[createDate,version]]'
+
+        if not filter_component:
+            filter_component = {"components": {
+                "hardwareComponentModel": {
+                    "firmwares": {
+                        "createDate": {
+                            "operation": "orderBy",
+                            "options": [
+                                {
+                                    "name": "sort",
+                                    "value": [
+                                        "DESC"
+                                    ]
+                                },
+                                {
+                                    "name": "sortOrder",
+                                    "value": [
+                                        1
+                                    ]}]}
+                    }}}}
+
+        return self.client.call('Hardware_Server', 'getComponents',
+                                mask=mask, filter=filter_component, id=hardware_id)
+
 
 def _get_bandwidth_key(items, hourly=True, no_public=False, location=None):
     """Picks a valid Bandwidth Item, returns the KeyName"""
