@@ -5,6 +5,7 @@
 
     :license: MIT, see LICENSE for more details.
 """
+import collections
 import datetime
 import re
 import time
@@ -57,6 +58,23 @@ class NestedDict(dict):
                 for key, val in self.items()}
 
 
+def dict_merge(dct1, dct2):
+    """Recursively merges dct2 and dct1, ideal for merging objectFilter together.
+
+    :param dct1: A dictionary
+    :param dct2: A dictionary
+    :return: dct1 + dct2
+    """
+
+    dct = dct1.copy()
+    for k, _ in dct2.items():
+        if (k in dct1 and isinstance(dct1[k], dict) and isinstance(dct2[k], collections.abc.Mapping)):
+            dct[k] = dict_merge(dct1[k], dct2[k])
+        else:
+            dct[k] = dct2[k]
+    return dct
+
+
 def query_filter(query):
     """Translate a query-style string to a 'filter'.
 
@@ -200,6 +218,26 @@ def event_log_filter_less_than_date(date, utc):
     }
 
 
+def build_filter_orderby(orderby):
+    """Builds filters using the filter options passed into the CLI.
+
+    It only supports the orderBy option, the default value is DESC.
+    """
+    _filters = {}
+    reverse_filter = list(reversed(orderby.split('.')))
+    for keyword in reverse_filter:
+        _aux_filter = {}
+        if '=' in keyword:
+            _aux_filter[str(keyword).split('=', maxsplit=1)[0]] = query_filter_orderby(str(keyword).split('=')[1])
+            _filters = _aux_filter
+        elif keyword == list(reverse_filter)[0]:
+            _aux_filter[keyword] = query_filter_orderby('DESC')
+        else:
+            _aux_filter[keyword] = _filters
+        _filters = _aux_filter
+    return _filters
+
+
 class IdentifierMixin(object):
     """Mixin used to resolve ids from other names of objects.
 
@@ -368,3 +406,24 @@ def trim_to(string, length=80, tail="..."):
         return string[:length] + tail
     else:
         return string
+
+
+def format_comment(comment, max_line_length=60):
+    """Return a string that is length long, added a next line and keep the table format.
+
+    :param string comment: String you want to add next line
+    :param int max_line_length: max length for the string
+    """
+    comment_length = 0
+    words = comment.split(" ")
+    formatted_comment = ""
+    for word in words:
+        if comment_length + (len(word) + 1) <= max_line_length:
+            formatted_comment = formatted_comment + word + " "
+
+            comment_length = comment_length + len(word) + 1
+        else:
+            formatted_comment = formatted_comment + "\n" + word + " "
+
+            comment_length = len(word) + 1
+    return formatted_comment
